Visualization API
================

The ``visualization`` module contains functions for creating static and interactive visualizations of hydro-topographic features.

.. automodule:: hydro_topo_features.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Static Visualization
------------------

.. automodule:: hydro_topo_features.visualization.static
   :members:
   :undoc-members:
   :show-inheritance:

Interactive Visualization
-----------------------

.. automodule:: hydro_topo_features.visualization.interactive
   :members:
   :undoc-members:
   :show-inheritance: 